@@ -7,6 +7,8 @@ import logging
 from pathlib import Path
 from typing import TYPE_CHECKING, Any
 
+from packaging.version import InvalidVersion, Version
+
 from ansiblelint.constants import RULE_DOC_URL
 
 if TYPE_CHECKING:
@@ -41,7 +43,7 @@ class BaseRule:
     id: str = ""
     tags: list[str] = []
     description: str = ""
-    version_added: str = ""
+    version_changed: str = ""
     severity: str = ""
     link: str = ""
     has_dynamic_tags: bool = False
@@ -56,6 +58,15 @@ class BaseRule:
     _help: str | None = None
     # Added when a rule is registered into a collection, gives access to options
     _collection: RulesCollection | None = None
+    # Allow rules to provide a custom short description instead of using __doc__
+    _shortdesc: str = ""
+
+    def __init__(self) -> None:
+        try:
+            Version(self.version_changed)
+        except InvalidVersion:
+            msg = f"Rule {self.__class__.__name__} has an invalid version_changed field '{self.version_changed}', is should be a 'X.Y.Z' format value."
+            _logger.warning(msg)
 
     @property
     def help(self) -> str:
@@ -83,7 +94,7 @@ class BaseRule:
     @property
     def shortdesc(self) -> str:
         """Return the short description of the rule, basically the docstring."""
-        return self.__doc__ or ""
+        return self._shortdesc or self.__doc__ or ""
 
     def getmatches(self, file: Lintable) -> list[MatchError]:
         """Return all matches while ignoring exceptions."""
@@ -96,7 +107,7 @@ class BaseRule:
                     _logger.warning(
                         "Ignored exception from %s.%s while processing %s: %s",
                         self.__class__.__name__,
-                        method,
+                        method.__name__,
                         str(file),
                         exc,
                     )
@@ -138,10 +149,6 @@ class BaseRule:
         """Return matches for lintable folders."""
         return []
 
-    def verbose(self) -> str:
-        """Return a verbose representation of the rule."""
-        return self.id + ": " + self.shortdesc + "\n  " + self.description
-
     def match(self, line: str) -> bool | str:
         """Confirm if current rule matches the given string."""
         return False
@@ -150,7 +157,7 @@ class BaseRule:
         """Enable us to sort rules by their id."""
         return (self._order, self.id) < (other._order, other.id)
 
-    def __repr__(self) -> str:
+    def __repr__(self) -> str:  # pragma: no cover
         """Return a AnsibleLintRule instance representation."""
         return self.id + ": " + self.shortdesc
 
@@ -165,19 +172,24 @@ class BaseRule:
     @property
     def rule_config(self) -> dict[str, Any]:
         """Retrieve rule specific configuration."""
-        rule_config = self.options.rules.get(self.id, {})
-        if not isinstance(rule_config, dict):  # pragma: no branch
+        rule_config = {}
+        if self.options:
+            rule_config = self.options.rules.get(self.id, {})
+        if not isinstance(rule_config, dict):  # pragma: no cover
             msg = f"Invalid rule config for {self.id}: {rule_config}"
-            raise RuntimeError(msg)
+            raise RuntimeError(msg)  # noqa: TRY004
         return rule_config
 
     @property
-    def options(self) -> Options:
+    def options(self) -> Options | None:
         """Used to access linter configuration."""
-        if self._collection is None:
+        if self.unloadable:
+            # internal rules are not configurable
+            return None
+        if self._collection is None:  # pragma: no cover
             msg = f"A rule ({self.id}) that is not part of a collection cannot access its configuration."
             _logger.warning(msg)
-            raise RuntimeError(msg)
+            return None
         return self._collection.options
 
 
@@ -188,10 +200,10 @@ class RuntimeErrorRule(BaseRule):
     """Unexpected internal error."""
 
     id = "internal-error"
-    shortdesc = "Unexpected internal error"
+    _shortdesc = "Unexpected internal error"
     severity = "VERY_HIGH"
     tags = ["core"]
-    version_added = "v5.0.0"
+    version_changed = "5.0.0"
     _order = 0
     unloadable = True
 
@@ -203,7 +215,7 @@ class AnsibleParserErrorRule(BaseRule):
     description = "Ansible parser fails; this usually indicates an invalid file."
     severity = "VERY_HIGH"
     tags = ["core"]
-    version_added = "v5.0.0"
+    version_changed = "5.0.0"
     _order = 0
     unloadable = True
 
@@ -215,7 +227,7 @@ class LoadingFailureRule(BaseRule):
     description = "Linter failed to process a file, possible invalid file."
     severity = "VERY_HIGH"
     tags = ["core", "unskippable"]
-    version_added = "v4.3.0"
+    version_changed = "4.3.0"
     _help = LOAD_FAILURE_MD
     _order = 0
     _ids = {
@@ -231,6 +243,6 @@ class WarningRule(BaseRule):
     severity = "LOW"
     # should remain experimental as that would keep it warning only
     tags = ["core", "experimental"]
-    version_added = "v6.8.0"
+    version_changed = "6.8.0"
     _order = 0
     unloadable = True
