@@ -61,7 +61,9 @@ def expand_to_normalized_paths(
         config[paths_var] = normalized_paths
 
 
-def load_config(config_file: str | None) -> tuple[dict[Any, Any], str | None]:
+def load_config(
+    config_file: str | None = None, project_path: str | None = None
+) -> tuple[dict[Any, Any], str | None]:
     """Load configuration from disk."""
     config_path = None
 
@@ -74,7 +76,7 @@ def load_config(config_file: str | None) -> tuple[dict[Any, Any], str | None]:
         if not os.path.exists(config_path):
             _logger.error("Config file not found '%s'", config_path)
             sys.exit(RC.INVALID_CONFIG)
-    config_path = config_path or get_config_path()
+    config_path = config_path or get_config_path(None, project_path=project_path)
     if not config_path or not os.path.exists(config_path):
         # a missing default config file should not trigger an error
         return {}, None
@@ -92,7 +94,7 @@ def load_config(config_file: str | None) -> tuple[dict[Any, Any], str | None]:
     config = clean_json(config_lintable.data)
     if not isinstance(config, dict):
         msg = "Schema failed to properly validate the config file."
-        raise RuntimeError(msg)
+        raise TypeError(msg)
     config["config_file"] = config_path
     config_dir = os.path.dirname(config_path)
     expand_to_normalized_paths(config, config_dir)
@@ -100,17 +102,21 @@ def load_config(config_file: str | None) -> tuple[dict[Any, Any], str | None]:
     return config, config_path
 
 
-def get_config_path(config_file: str | None = None) -> str | None:
+def get_config_path(
+    config_file: str | None = None, project_path: str | None = None
+) -> str | None:
     """Return local config file."""
     if config_file:
         project_filenames = [config_file]
     else:
         project_filenames = [
             ".ansible-lint",
+            ".ansible-lint.yml",
+            ".ansible-lint.yaml",
             ".config/ansible-lint.yml",
             ".config/ansible-lint.yaml",
         ]
-    parent = tail = os.getcwd()
+    parent = tail = project_path or os.getcwd()
     while tail:
         for project_filename in project_filenames:
             filename = os.path.abspath(os.path.join(parent, project_filename))
@@ -135,6 +141,7 @@ class AbspathArgAction(argparse.Action):
         values: str | Sequence[Any] | None,
         option_string: str | None = None,
     ) -> None:
+        _logger.debug(option_string)
         if isinstance(values, str | Path):
             values = [values]
         if values:
@@ -151,7 +158,7 @@ class WriteArgAction(argparse.Action):
     _default = "__default__"
 
     # noinspection PyShadowingBuiltins
-    def __init__(  # pylint: disable=too-many-arguments,redefined-builtin
+    def __init__(  # pylint: disable=too-many-arguments,redefined-builtin,too-many-positional-arguments
         self,
         option_strings: list[str],
         dest: str,
@@ -208,7 +215,7 @@ class WriteArgAction(argparse.Action):
         if not values:
             values = previous_values
         elif previous_values != default:
-            values = previous_values + values
+            values = previous_values + values  # type: ignore[operator]
         setattr(namespace, self.dest, values)
 
     @classmethod
@@ -254,7 +261,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="list_profiles",
         default=False,
         action="store_true",
-        help="List all profiles, no formatting options available.",
+        help="List all profiles.",
     )
     listing_group.add_argument(
         "-L",
@@ -262,16 +269,14 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="list_rules",
         default=False,
         action="store_true",
-        help="List all the rules. For listing rules only the following formats "
-        "for argument -f are supported: {brief, full, md} with 'brief' as default.",
+        help="List all the rules.",
     )
     listing_group.add_argument(
         "-T",
         "--list-tags",
         dest="list_tags",
         action="store_true",
-        help="List all the tags and the rules they cover. Increase the verbosity level "
-        "with `-v` to include 'opt-in' tag and its rules.",
+        help="List all the tags and the rules they cover.",
     )
     parser.add_argument(
         "-f",
@@ -446,7 +451,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         "-c",
         "--config-file",
         dest="config_file",
-        help="Specify configuration file to use. By default it will look for '.ansible-lint', '.config/ansible-lint.yml', or '.config/ansible-lint.yaml'",
+        help="Specify configuration file to use. By default it will look for '.ansible-lint', '.ansible-lint.yml', '.ansible-lint.yaml', '.config/ansible-lint.yml', or '.config/ansible-lint.yaml'",
     )
     parser.add_argument(
         "-i",
@@ -459,8 +464,8 @@ def get_cli_parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "--offline",
         dest="offline",
-        action="store_const",
-        const=True,
+        action=argparse.BooleanOptionalAction,
+        default=False,
         help="Disable installation of requirements.yml and schema refreshing",
     )
     parser.add_argument(
@@ -499,6 +504,7 @@ def merge_config(file_config: dict[Any, Any], cli_config: Options) -> Options:
         "enable_list": [],
         "only_builtins_allow_collections": [],
         "only_builtins_allow_modules": [],
+        "supported_ansible_also": [],
         # do not include "write_list" here. See special logic below.
     }
 
@@ -517,7 +523,7 @@ def merge_config(file_config: dict[Any, Any], cli_config: Options) -> Options:
                 setattr(cli_config, entry, default)
         if cli_config.write_list is None:
             cli_config.write_list = []
-        elif cli_config.write_list == [WriteArgAction._default]:  # noqa: SLF001
+        elif cli_config.write_list == [WriteArgAction._default]:  # noqa: SLF001 # pragma: no cover
             cli_config.write_list = ["all"]
         return cli_config
 
@@ -526,8 +532,8 @@ def merge_config(file_config: dict[Any, Any], cli_config: Options) -> Options:
         v = getattr(cli_config, entry) or file_value
         setattr(cli_config, entry, v)
 
-    for entry, default in scalar_map.items():
-        file_value = file_config.pop(entry, default)
+    for entry, default_scalar in scalar_map.items():
+        file_value = file_config.pop(entry, default_scalar)
         v = getattr(cli_config, entry, None) or file_value
         setattr(cli_config, entry, v)
 
@@ -593,7 +599,9 @@ def get_config(arguments: list[str]) -> Options:
         )
 
     # save info about custom config file, as options.config_file may be modified by merge_config
-    file_config, options.config_file = load_config(options.config_file)
+    file_config, options.config_file = load_config(
+        options.config_file, project_path=options.project_dir
+    )
     config = merge_config(file_config, options)
 
     options.rulesdirs = get_rules_dirs(
@@ -610,7 +618,7 @@ def get_config(arguments: list[str]) -> Options:
         log_entries.append(
             (
                 logging.INFO,
-                f"Identified [filename]{project_dir}[/] as project root due [bold]{method}[/].",
+                f"Identified [repr.path]{project_dir}[/] as project root due [bold]{method}[/].",
             ),
         )
 
