@@ -568,22 +568,29 @@ class HandleChildren:
 
     def _rolepath(self, basedir: str, role: str) -> str | None:
         role_path = None
-        namespace_name, collection_name, role_name = parse_fqcn(role)
+        namespace_name, collection_name, *role_name = parse_fqcn(role)
 
         possible_paths = [
             # if included from a playbook
-            path_dwim(basedir, os.path.join("roles", role_name)),
-            path_dwim(basedir, role_name),
+            path_dwim(basedir, os.path.join("roles", role_name[-1])),
+            path_dwim(basedir, role_name[-1]),
             # if included from roles/[role]/meta/main.yml
-            path_dwim(basedir, os.path.join("..", "..", "..", "roles", role_name)),
-            path_dwim(basedir, os.path.join("..", "..", role_name)),
+            path_dwim(basedir, os.path.join("..", "..", "..", "roles", role_name[-1])),
+            path_dwim(basedir, os.path.join("..", "..", role_name[-1])),
             # if checking a role in the current directory
-            path_dwim(basedir, os.path.join("..", role_name)),
+            path_dwim(basedir, os.path.join("..", role_name[-1])),
         ]
+        if len(role_name) > 1:
+            # This ignores deeper structures than 1 level
+            possible_paths.append(path_dwim(basedir, os.path.join("roles", *role_name)))
+            possible_paths.append(path_dwim(basedir, os.path.join(*role_name)))
+            possible_paths.append(
+                path_dwim(basedir, os.path.join("..", "..", *role_name))
+            )
 
         for loc in self.app.runtime.config.default_roles_path:
             loc = os.path.expanduser(loc)
-            possible_paths.append(path_dwim(loc, role_name))
+            possible_paths.append(path_dwim(loc, role_name[-1]))
 
         if namespace_name and collection_name:
             for loc in get_app(cached=True).runtime.config.collections_paths:
@@ -596,7 +603,7 @@ class HandleChildren:
                             namespace_name,
                             collection_name,
                             "roles",
-                            role_name,
+                            role_name[-1],
                         ),
                     ),
                 )
@@ -1160,8 +1167,8 @@ def parse_yaml_linenumbers(
         yaml.constructor.ConstructorError,
         ruamel.yaml.parser.ParserError,
     ) as exc:
-        msg = f"Failed to load YAML file: {lintable.path}"
-        raise RuntimeError(msg) from exc
+        msg = "Failed to load YAML file"
+        raise RuntimeError(msg, lintable.path) from exc
 
     if len(result) == 0:
         return None  # empty documents
@@ -1214,6 +1221,7 @@ def is_playbook(filename: str) -> bool:
         "gather_facts",
         "hosts",
         "import_playbook",
+        "ansible.builtin.import_playbook",
         "post_tasks",
         "pre_tasks",
         "roles",
@@ -1342,4 +1350,7 @@ def load_plugin(name: str) -> PluginLoadContext:
 
 def parse_fqcn(name: str) -> tuple[str, ...]:
     """Parse name parameter into FQCN segments."""
-    return tuple(name.split(".")) if is_fqcn(name) else ("", "", name)
+    if not is_fqcn(name):
+        return ("", "", name)
+
+    return tuple(name.split("."))
